using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Text;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Shared.Utilities;
using Vevo.Shared.DataAccess;
using Vevo.Domain.Users;
using Vevo.Base.Data;
using Vevo.Base.Domain;

namespace Vevo.Data
{
    public class AdminRepositoryNoCache : IAdminRepository
    {
        #region Private

        private const string AllAdminFields = "AdminID, RegisterDate, UserName , Email ";

        private Admin Create( Admin admin )
        {
            string adminID = DataAccess.ExecuteScalar(
               "INSERT INTO Admin ( UserName , Email ) " +
               "VALUES ( @UserName , @Email ); " +
               "SELECT @@Identity; ",
               DataAccess.CreateParameterString( admin.UserName ),
               DataAccess.CreateParameterString( admin.Email )
            );

            admin.AdminID = adminID;

            return admin;

        }

        private Admin Update( Admin admin )
        {
            DataAccess.ExecuteNonQuery(
                "UPDATE Admin " +
                "SET RegisterDate = @RegisterDate, " +
                "    UserName = @UserName , " +
                "    Email = @Email " +
                "WHERE AdminID = @AdminID; ",
                DataAccess.CreateParameterDateTime( admin.RegisterDate.Date ),
                DataAccess.CreateParameterString( admin.UserName ),
                DataAccess.CreateParameterString( admin.Email ),
                DataAccess.CreateParameterString( admin.AdminID )
            );

            return admin;
        }

        private Admin CreateOneFromRow( DataRow row )
        {
            Admin admin = new Admin();
            admin.AdminID = row["AdminID"].ToString();
            admin.RegisterDate = ConvertUtilities.ToDateTime( row["RegisterDate"] );
            admin.UserName = row["UserName"].ToString();
            admin.Email = row["Email"].ToString();

            return admin;
        }

        private IList<Admin> ConvertTableToList( DataTable table, int startIndex, int endIndex )
        {
            IList<Admin> list = new List<Admin>();

            for (int i = startIndex; i <= endIndex && i < table.Rows.Count; i++)
                list.Add( CreateOneFromRow( table.Rows[i] ) );

            return list;
        }

        private string CreateSortByText( string sortBy )
        {
            if (sortBy == null || sortBy.Trim() == "")
                return "";
            else
                return "ORDER BY " + sortBy;
        }

        #endregion


        #region Public Methods

        public Admin Save( Admin admin )
        {
            Admin result;

            if (admin.AdminID == "0")
                result = Create( admin );
            else
                result = Update( admin );

            return result;
        }

        public Admin GetOne( string adminID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllAdminFields +
                "FROM Admin " +
                "WHERE AdminID = @AdminID; ",
                DataAccess.CreateParameterString( adminID ) );

            if (table.Rows.Count > 0)
                return CreateOneFromRow( table.Rows[0] );
            else
                return Admin.Null;
        }

        public string GetIDFromUserName( string userName )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT AdminID " +
                "FROM Admin " +
                "WHERE UserName = @UserName; ",
                DataAccess.CreateParameterString( userName ) );

            if (table.Rows.Count > 0)
                return table.Rows[0]["AdminID"].ToString();
            else
                return "0";
        }

        public void Delete( string adminID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM Admin WHERE AdminID = @AdminID ",
                DataAccess.CreateParameterString( adminID )
            );
        }

        public IList<Admin> SearchAdmin(
            string sortBy,
            SearchFilter searchFilter,
            int startIndex,
            int endIndex,
            out int howManyItems )
        {
            ArrayList parameterList = new ArrayList();
            SearchFilterHelperNew searchFilterHelper = new SearchFilterHelperNew();
            string commandSearch = searchFilterHelper.CreateCommandWithWhere( searchFilter, searchFilter.FieldName, parameterList );

            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllAdminFields + " " +
                "FROM Admin " +
                commandSearch +
                CreateSortByText( sortBy ) + "; ",
                DataAccess.ConvertArrayListToDbParameters( parameterList )
                );

            howManyItems = table.Rows.Count;

            DataColumn[] keys = new DataColumn[] { table.Columns["AdminID"] };
            table.PrimaryKey = keys;
            return ConvertTableToList( table, startIndex, endIndex );
        }

        public IList<TableSchemaItem> GetTableSchema()
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllAdminFields +
                "FROM Admin " +
                "WHERE 0 = 1; " );

            return RepositoryUtilities.ConvertTableToSchemaItemList( table );
        }

        #endregion
    }
}
