﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data;

using Vevo.Domain.Products;
using Vevo.Shared.DataAccess;
using Vevo.Shared.Utilities;
using Vevo.Domain.Stores;
using Vevo.Domain;

namespace Vevo.Data.Implementation
{
    internal class ProductPriceAccess
    {
        #region Private

        private ProductPrice CreateOneFromRow( DataRow row )
        {
            ProductPrice productPrice = new ProductPrice();
            productPrice.ProductID = row["ProductID"].ToString();
            productPrice.StoreID = row["StoreID"].ToString();
            productPrice.Price = ConvertUtilities.ToDecimal( row["Price"] );
            productPrice.RetailPrice = ConvertUtilities.ToDecimal( row["RetailPrice"] );
            productPrice.WholesalePrice = ConvertUtilities.ToDecimal( row["WholesalePrice"] );
            productPrice.WholesalePrice2 = ConvertUtilities.ToDecimal( row["WholesalePrice2"] );
            productPrice.WholesalePrice3 = ConvertUtilities.ToDecimal( row["WholesalePrice3"] );
            productPrice.UseDefaultPrice = ConvertUtilities.ToBoolean( row["UseDefaultPrice"] );
            productPrice.UseDefaultRetailPrice = ConvertUtilities.ToBoolean( row["UseDefaultRetailPrice"] );
            productPrice.UseDefaultWholeSalePrice = ConvertUtilities.ToBoolean( row["UseDefaultWholeSalePrice"] );
            productPrice.UseDefaultWholeSalePrice2 = ConvertUtilities.ToBoolean( row["UseDefaultWholeSalePrice2"] );
            productPrice.UseDefaultWholeSalePrice3 = ConvertUtilities.ToBoolean( row["UseDefaultWholeSalePrice3"] );


            return productPrice;
        }

        private IList<ProductPrice> ConvertTableToList( DataTable table )
        {
            IList<ProductPrice> list = new List<ProductPrice>();
            foreach (DataRow row in table.Rows)
            {
                list.Add( CreateOneFromRow( row ) );
            }

            return list;
        }


        #endregion

        #region Public Methods

        public void SaveAll( Product product, IList<ProductPrice> productPrices )
        {
            DeleteByProductID( product.ProductID );
            Create( product, productPrices );
        }

        public void Create( Product product, IList<ProductPrice> productPrices )
        {
            foreach (ProductPrice productPrice in productPrices)
            {
                int result = DataAccess.ExecuteNonQuery(
                    "INSERT INTO ProductPrice ( ProductID, StoreID, Price, RetailPrice, WholesalePrice, WholesalePrice2, WholesalePrice3,  " +
                    " UseDefaultPrice, UseDefaultRetailPrice, UseDefaultWholeSalePrice, UseDefaultWholeSalePrice2, UseDefaultWholeSalePrice3 ) " +
                    "VALUES ( @ProductID, @StoreID, @Price, @RetailPrice, @WholesalePrice, @WholesalePrice2, @WholesalePrice3, " +
                    " @UseDefaultPrice, @UseDefaultRetailPrice, @UseDefaultWholeSalePrice, @UseDefaultWholeSalePrice2, @UseDefaultWholeSalePrice3 );",
                    DataAccess.CreateParameterString( product.ProductID ),
                    DataAccess.CreateParameterString( productPrice.StoreID ),
                    DataAccess.CreateParameterDecimalMoney( productPrice.Price ),
                    DataAccess.CreateParameterDecimalMoney( productPrice.RetailPrice ),
                    DataAccess.CreateParameterDecimalMoney( productPrice.WholesalePrice ),
                    DataAccess.CreateParameterDecimalMoney( productPrice.WholesalePrice2 ),
                    DataAccess.CreateParameterDecimalMoney( productPrice.WholesalePrice3 ),
                    DataAccess.CreateParameterBool( productPrice.UseDefaultPrice ),
                    DataAccess.CreateParameterBool( productPrice.UseDefaultRetailPrice ),
                    DataAccess.CreateParameterBool( productPrice.UseDefaultWholeSalePrice ),
                    DataAccess.CreateParameterBool( productPrice.UseDefaultWholeSalePrice2 ),
                    DataAccess.CreateParameterBool( productPrice.UseDefaultWholeSalePrice3 ) );
            }


        }

        public void Create( Product product, ProductPrice productPrice, string storeID )
        {
            DataAccess.ExecuteNonQuery(
                    "INSERT INTO ProductPrice ( ProductID, StoreID, Price, RetailPrice, WholesalePrice, WholesalePrice2, WholesalePrice3, " +
                    " UseDefaultPrice, UseDefaultRetailPrice, UseDefaultWholeSalePrice, UseDefaultWholeSalePrice2, UseDefaultWholeSalePrice3 ) " +
                    "VALUES ( @ProductID, @StoreID, @Price, @RetailPrice, @WholesalePrice, @WholesalePrice2, @WholesalePrice3, " +
                    " @UseDefaultPrice, @UseDefaultRetailPrice, @UseDefaultWholeSalePrice, @UseDefaultWholeSalePrice2, @UseDefaultWholeSalePrice3 );",
                    DataAccess.CreateParameterString( product.ProductID ),
                    DataAccess.CreateParameterString( storeID ),
                    DataAccess.CreateParameterDecimalMoney( productPrice.Price ),
                    DataAccess.CreateParameterDecimalMoney( productPrice.RetailPrice ),
                    DataAccess.CreateParameterDecimalMoney( productPrice.WholesalePrice ),
                    DataAccess.CreateParameterDecimalMoney( productPrice.WholesalePrice2 ),
                    DataAccess.CreateParameterDecimalMoney( productPrice.WholesalePrice3 ),
                    DataAccess.CreateParameterBool( productPrice.UseDefaultPrice ),
                    DataAccess.CreateParameterBool( productPrice.UseDefaultRetailPrice ),
                    DataAccess.CreateParameterBool( productPrice.UseDefaultWholeSalePrice ),
                    DataAccess.CreateParameterBool( productPrice.UseDefaultWholeSalePrice2 ),
                    DataAccess.CreateParameterBool( productPrice.UseDefaultWholeSalePrice3 ) );
        }

        public void DeleteByProductID( string productID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM ProductPrice " +
                "WHERE ProductID = @ProductID;",
                DataAccess.CreateParameterString( productID ) );
        }

        public void DeleteByStoreID( string storeID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM ProductPrice " +
                "WHERE StoreID = @StoreID;",
                DataAccess.CreateParameterString( storeID ) );
        }

        public void CreateFromDefaultByStoreID( string storeID )
        {
            DataAccess.ExecuteNonQuery(
                "INSERT INTO ProductPrice( ProductID, StoreID, Price, RetailPrice, " +
                "WholesalePrice, WholesalePrice2, WholesalePrice3,UseDefaultPrice, UseDefaultRetailPrice, " +
                "UseDefaultWholeSalePrice, UseDefaultWholeSalePrice2, UseDefaultWholeSalePrice3 ) " +
                "(SELECT pp.ProductID, @StoreID , pp.Price, pp.RetailPrice, pp.WholesalePrice, " +
                "pp.WholesalePrice2, pp.WholesalePrice3,pp.UseDefaultPrice, pp.UseDefaultRetailPrice, " +
                "pp.UseDefaultWholeSalePrice, pp.UseDefaultWholeSalePrice2, pp.UseDefaultWholeSalePrice3 " +
                "from ProductPrice pp where StoreID = 0);",
                DataAccess.CreateParameterString( storeID ) );
        }

        public IList<ProductPrice> GetByProductID( string productID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductID, StoreID, Price, RetailPrice, WholesalePrice, WholesalePrice2, WholesalePrice3, " +
                "UseDefaultPrice, UseDefaultRetailPrice, UseDefaultWholeSalePrice, UseDefaultWholeSalePrice2, UseDefaultWholeSalePrice3 " +
                "FROM ProductPrice " +
                "WHERE ProductID = @ProductID;",
                DataAccess.CreateParameterString( productID ) );

            return ConvertTableToList( table );
        }

        public ProductPrice GetDefaultProductPrice( string productID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductID, StoreID, Price, RetailPrice, WholesalePrice, WholesalePrice2, WholesalePrice3, " +
                "UseDefaultPrice, UseDefaultRetailPrice, UseDefaultWholeSalePrice, UseDefaultWholeSalePrice2, UseDefaultWholeSalePrice3 " +
                "FROM ProductPrice " +
                "WHERE ProductID = @ProductID AND StoreID = 0;",
                DataAccess.CreateParameterString( productID ) );

            if (table.Rows.Count > 0)
                return CreateOneFromRow( table.Rows[0] );
            else
                return new ProductPrice();
        }

        public IList<ProductPrice> GetDefaultProductPriceList()
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductID, StoreID, Price, RetailPrice, WholesalePrice, WholesalePrice2, WholesalePrice3, " +
                "UseDefaultPrice, UseDefaultRetailPrice, UseDefaultWholeSalePrice, UseDefaultWholeSalePrice2, UseDefaultWholeSalePrice3 " +
                "FROM ProductPrice " +
                "WHERE StoreID = 0;" );

            return ConvertTableToList( table );
        }

        #endregion
    }
}
