using System;
using System.Collections;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using System.Xml.Serialization;
using Vevo.Shared.Domain.SystemServices;
using System.IO;

namespace Vevo.Domain.International
{
    [XmlRoot( ElementName = "CountryList" )]
    public class StandardCountryCollection : CollectionBase
    {
        #region Public Constances

        public const string CountryListFilePath = "~/DataFiles/CountryList.xml";

        #endregion


        #region Private

        private static StandardCountryCollection _countryCollection;

        #endregion


        #region Constructors

        private StandardCountryCollection()
        {
        }

        #endregion


        #region Public Properties

        public StandardCountry this[int index]
        {
            get
            {
                return (StandardCountry) this.InnerList[index];
            }
            set
            {
                this.InnerList[index] = value;
            }
        }

        #endregion


        #region Public Methods

        public static StandardCountryCollection Create( IFileManager fileManager )
        {
            if (_countryCollection == null)
            {
                XmlSerializer xmlSerializer = new XmlSerializer(
                    typeof( StandardCountryCollection ),
                    new Type[] { typeof( StandardCountry ) } );

                TextReader textReader = fileManager.CreateTextReader( CountryListFilePath );
                object collection = xmlSerializer.Deserialize( textReader );

                _countryCollection = (StandardCountryCollection) collection;
            }

            return _countryCollection;
        }

        public static void ClearCache()
        {
            _countryCollection = null;
        }

        public virtual void Add( StandardCountry country )
        {
            this.InnerList.Add( country );
        }

        public StandardCountry GetCountry( string countryCode )
        {
            foreach (object country in InnerList)
            {
                StandardCountry standardCountry = (StandardCountry) country;
                if (String.Compare( standardCountry.CountryCode, countryCode, true ) == 0)
                    return standardCountry;
            }

            return null;
        }

        #endregion
    }
}
