using System;
using System.Data;
using System.Collections;
using System.Collections.Generic;
using System.Configuration;

using Vevo.Domain.Users;

namespace Vevo.Domain.Orders
{
    /// <summary>
    /// Summary description for CartItemGroup
    /// </summary>
    public class CartItemGroup
    {
        #region Private

        private IList<ICartItem> _cartItems;

        #endregion


        #region Constructors

        public CartItemGroup( params ICartItem[] cartItems )
        {
            _cartItems = cartItems;
        }

        public CartItemGroup( IList<ICartItem> cartItems )
        {
            _cartItems = cartItems;
        }

        #endregion


        #region Public Properties

        public IList<ICartItem> CartItems
        {
            get { return _cartItems; }
        }

        public bool IsRecurring
        {
            get
            {
                if (CartItems.Count > 0)
                    return CartItems[0].Product.IsRecurring;
                else
                    return false;
            }
        }

        public bool HasTrialPeriod
        {
            get
            {
                if (CartItems.Count > 0)
                    return CartItems[0].Product.HasTrialPeriod;
                else
                    return false;
            }
        }

        #endregion


        #region Public Methods

        public ICartItem[] GetCartItemArray()
        {
            ICartItem[] array = new ICartItem[_cartItems.Count];
            _cartItems.CopyTo( array, 0 );
            return array;
        }

        public double GetTotalWeight()
        {
            double totalWeight = 0;
            foreach (ICartItem cartItem in _cartItems)
            {
                totalWeight += cartItem.Quantity * cartItem.UnitWeight;
            }
            return totalWeight;
        }

        public decimal GetSubtotal( WholesaleStatus wholesaleStatus )
        {
            decimal subtotal = 0;
            foreach (ICartItem cartItem in _cartItems)
            {
                subtotal += cartItem.GetSubtotal( wholesaleStatus );
            }
            return subtotal;
        }

        public CartItemGroup CreateRegularRecurringGroup()
        {
            List<ICartItem> list = new List<ICartItem>();

            foreach (ICartItem cartItem in CartItems)
            {
                if (cartItem.IsRecurring)
                    list.Add( new RegularRecurringCartItem((CartItem) cartItem ) );
            }

            return new CartItemGroup( list );
        }

        #endregion

    }
}
