using System;
using System.Collections.Generic;
using System.Text;

namespace Vevo.Domain.Orders
{
    public class OrderItem : ICloneable
    {
        #region Private

        private string _orderItemID = "0";
        private string _orderID = "0";
        private string _productID = "0";
        private string _name = String.Empty;
        private int _quantity = 0;
        private string _sku = String.Empty;
        private string _model = String.Empty;
        private decimal _unitPrice = 0;
        private string _giftRegistryItemID = "0";
        private string _uploadFile = String.Empty;
        private string _recurringID = "0";
        private OrderItemRecurring _orderItemRecurring = new OrderItemRecurring();
        private int _downloadCount = 0;

        private string TrimPriceInOption( string optionName )
        {
            string[] filenames = optionName.Split( new string[] { " (" }, StringSplitOptions.None );
            string outputFilename = String.Empty;
            if (filenames[filenames.Length - 1].EndsWith( ")" ))
            {
                for (int i = 0; i < filenames.Length - 1; i++)
                    outputFilename += filenames[i];
            }
            else
            {
                outputFilename = optionName;
            }
            return outputFilename;
        }
        #endregion


        #region Public Constructors

        public OrderItem()
        {
        }

        #endregion


        #region Public Properties

        public string OrderItemID { get { return _orderItemID; } set { _orderItemID = value; } }
        public string OrderID { get { return _orderID; } set { _orderID = value; } }
        public string ProductID { get { return _productID; } set { _productID = value; } }
        public string Name { get { return _name; } set { _name = value; } }
        public int Quantity { get { return _quantity; } set { _quantity = value; } }
        public string Sku { get { return _sku; } set { _sku = value; } }
        public string Model { get { return _model; } set { _model = value; } }
        public decimal UnitPrice { get { return _unitPrice; } set { _unitPrice = value; } }
        public string GiftRegistryItemID { get { return _giftRegistryItemID; } set { _giftRegistryItemID = value; } }
        public string UploadFile { get { return _uploadFile; } set { _uploadFile = value; } }
        public string RecurringID { get { return _recurringID; } set { _recurringID = value; } }
        public OrderItemRecurring OrderItemRecurring { get { return _orderItemRecurring; } set { _orderItemRecurring = value; } }
        public int DownloadCount { get { return _downloadCount; } set { _downloadCount = value; } }

        public decimal ItemSubtotal
        {
            get
            {
                return UnitPrice * Quantity;
            }
        }

        #endregion


        #region IClonable Members

        // Copy the whole aggregate (including locale)
        public object Clone()
        {
            OrderItem newObject = (OrderItem) MemberwiseClone();
            return newObject;
        }

        #endregion


        #region Public Methods

        public string GetPlainTextName()
        {
            return Name.Replace( "<br>", ", " );
        }

        public IList<string> GetUploadedOptionNames()
        {
            IList<string> list = new List<string>();

            string[] optionNames = UploadFile.Split( ',' );

            foreach (string optionName in optionNames)
            {
                list.Add( TrimPriceInOption(optionName.Trim()) );
            }

            return list;
        }

        public string GenerateUploadedFileName( string optionName )
        {
            return TrimPriceInOption(OrderID + "_" + ProductID + "_" + optionName.Trim().Replace( " : ", "_" ).Replace( ',', ' ' ));
        }

        #endregion

    }
}
