using System;
using System.Collections.Generic;
using System.Text;

using Vevo.Domain.Base;
using Vevo.Shared.Utilities;
using Vevo.Domain.Users;
using Vevo.Base.Domain;

namespace Vevo.Domain.Tax
{
    public class TaxClass
    {
        #region Private

        private string _taxClassID = "0";
        private string _taxClassName = String.Empty;

        //------------------------------------------------------------
        // Custom private members

        private IEntityList<TaxClassRule> _taxClassRule;

        #endregion

        #region Public Properties

        public static TaxClass Null
        {
            get { return NullTaxClass.Instance; }
        }

        public virtual bool IsNull
        {
            get { return false; }
        }

        public const string RegularTaxClassID = "1";

        public const string NonTaxClassID = "0";


        public string TaxClassID { get { return _taxClassID; } set { _taxClassID = value; } }
        public string TaxClassName { get { return _taxClassName; } set { _taxClassName = value; } }

        #endregion

        #region Custom Properties

        public IEntityList<TaxClassRule> TaxClassRule
        {
            get
            {
                if (_taxClassRule == null)
                    _taxClassRule = new EntityList<TaxClassRule>(
                        DataAccessContext.TaxClassRepository.GetTaxClassRulesByTaxClassID( TaxClassID ) );

                return _taxClassRule;
            }
        }

        #endregion

        #region Public Method

        public double GetTaxRate( Address address )
        {
            // Specify Zip Code
            for (int i = 0; i < TaxClassRule.Count; i++)
            {
                if (TaxClassRule[i].CountryCode == address.Country
                    && TaxClassRule[i].StateCode == address.State
                    && TaxClassRule[i].ZipCode == address.Zip)
                {
                    return ConvertUtilities.ToDouble( TaxClassRule[i].TaxRate );
                }
            }

            // Specify Zip Code without state
            for (int i = 0; i < TaxClassRule.Count; i++)
            {
                if (TaxClassRule[i].CountryCode == address.Country
                    && TaxClassRule[i].StateCode == String.Empty
                    && TaxClassRule[i].ZipCode == address.Zip)
                {
                    return ConvertUtilities.ToDouble( TaxClassRule[i].TaxRate );
                }
            }

            // Default Zip Code; specify state
            for (int i = 0; i < TaxClassRule.Count; i++)
            {
                if (TaxClassRule[i].CountryCode == address.Country
                    && TaxClassRule[i].StateCode == address.State
                    && TaxClassRule[i].ZipCode == String.Empty)
                {
                    return ConvertUtilities.ToDouble( TaxClassRule[i].TaxRate );
                }
            }

            // Default State Code
            for (int i = 0; i < TaxClassRule.Count; i++)
            {
                if (TaxClassRule[i].CountryCode == address.Country
                    && TaxClassRule[i].StateCode == String.Empty
                    && TaxClassRule[i].ZipCode == String.Empty)
                {
                    return ConvertUtilities.ToDouble( TaxClassRule[i].TaxRate );
                }
            }

            // Default Country (everywhere)
            for (int i = 0; i < TaxClassRule.Count; i++)
            {
                if (TaxClassRule[i].CountryCode == String.Empty
                    && TaxClassRule[i].StateCode == String.Empty
                    && TaxClassRule[i].ZipCode == String.Empty)
                {
                    return ConvertUtilities.ToDouble( TaxClassRule[i].TaxRate );
                }
            }

            return 0;
        }

        #endregion
    }
}
