using System;
using System.Collections.Generic;
using Vevo.Domain;
using Vevo.Domain.Products;
using Vevo.QuickBooks.Qbxml70;

namespace Vevo.QuickBooks.States
{
    /// <summary>
    /// Summary description for ProductQueryRequestState
    /// </summary>
    public class ProductQueryRequestState : QBWCState
    {
        private void MoveToNextState()
        {
            QBWCSession.CurrentState = new ProductQueryResponseState( QBWCSession );
        }

        private void MoveProductModifyState()
        {
            QBWCSession.CurrentState = new ProductModifyRequestState( QBWCSession );
        }

        private IList<Product> GetAllData()
        {
            string cultureID = DataAccessContext.CultureRepository.GetIDByName(
                DataAccessContext.Configurations.GetValue( "DefaultWebsiteLanguage" ) );
            Culture culture = DataAccessContext.CultureRepository.GetOne( cultureID );

            string storeID = DataAccessContext.Configurations.GetValue( "QBSelectStoreExport" );
            string rootCategoryID = DataAccessContext.Configurations.GetValue( "0", "RootCategory", storeID );

            IList<Product> table = DataAccessContext.ProductRepository.GetAllQBProduct( culture, rootCategoryID, storeID );

            return table;
        }

        private ItemNonInventoryQueryRqType CreateOneRequest( Product product )
        {
            ItemNonInventoryQueryRqType req = new ItemNonInventoryQueryRqType();
            NameRangeFilter filter = new NameRangeFilter();
            filter.FromName = QBUtilities.LimitLength( product.Name, QBConst.ProductNameMaxLength );
            filter.ToName = QBUtilities.LimitLength( product.Name, QBConst.ProductNameMaxLength ) + "z";
            req.Items = new object[] { filter };
            req.ItemsElementName = new ItemsChoiceType44[] { ItemsChoiceType44.NameRangeFilter };
            return req;
        }

        private string CreateProductQuery( out bool xmlReady )
        {
            // Write QBXML
            IList<Product> table = GetAllData();
            if (table.Count == 0)
            {
                xmlReady = false;
                MoveProductModifyState();
                return String.Empty;
            }

            QBXML qbxml = CreateRequestQbxml();
            object[] requests = new object[table.Count];
            int index = 0;
            foreach (Product product in table)
            {
                requests[index] = CreateOneRequest( product );
                index++;
            }

            ((QBXMLMsgsRq) qbxml.Items[0]).Items = requests;

            xmlReady = true;
            string xml = CreateRequestXml( qbxml );
            return xml;
        }

        public ProductQueryRequestState( QBWCSession session )
            : base( session )
        {
        }

        public override string OnSendRequestXml( out bool xmlReady )
        {
            MoveToNextState();

            return CreateProductQuery( out xmlReady );
        }
    }
}
