﻿using System;
using System.Collections.Generic;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Products;
using Vevo.WebAppLib;
using Vevo.WebServices.SearchFilters;
using Vevo.WebServices.Security;
using Vevo.Base.Domain;

namespace Vevo.WebServices.Categories
{
    public class CategoryService : ICategoryService
    {
        private CategoryConstraints ConvertCategoryToConstraints( Category category, Culture culture )
        {
            CategoryConstraints constraints = new CategoryConstraints();
            constraints.CategoryID = category.CategoryID;
            constraints.CategoryListLayoutPath = category.CategoryListLayoutPath;
            constraints.Description = category.Description;
            constraints.DiscountGroupID = category.DiscountGroupID;
            constraints.ImageFile = category.ImageFile;
            constraints.IsEnabled = category.IsEnabled;
            constraints.MetaDescription = category.GetMetaDescription( culture );
            constraints.MetaKeyword = category.GetMetaKeyword( culture );
            constraints.Name = category.Name;
            constraints.Other1 = category.Other1;
            constraints.Other2 = category.Other2;
            constraints.Other3 = category.Other3;
            constraints.Other4 = category.Other4;
            constraints.Other5 = category.Other5;
            constraints.ParentCategoryID = category.ParentCategoryID;
            constraints.ProductListLayoutPath = category.ProductListLayoutPath;
            constraints.RootID = category.RootID;
            constraints.SortOrder = category.SortOrder;
            constraints.UrlName = category.UrlName;
            constraints.IsAnchor = category.IsAnchor;
            constraints.ImageAlt = category.ImageAlt;
            constraints.ImageTitle = category.ImageTitle;
            constraints.IsShowNewArrival = category.IsShowNewArrival;
            constraints.NewArrivalAmount = category.NewArrivalAmount;
            return constraints;
        }

        public CategoryListResponseMessage ListCategories( CategoryListRequestMessage ListMessage )
        {
            CategoryListResponseMessage responseMessage = new CategoryListResponseMessage();
            if (WcfSessionPool.GetSession( ListMessage.Ticket ) == null)
            {
                responseMessage.ErrorMessage = "Error: Authentication is failed.";
                return responseMessage;
            }
            try
            {
                SearchFilter searchFilter = SearchFilterUtilities.ConvertConstraintToSearchFilter( ListMessage.SearchFilter );
                Culture culture = DataAccessContext.CultureRepository.GetOne( ListMessage.CultureID );
                IList<Category> category_result = DataAccessContext.CategoryRepository.SearchCategoryByRootID( culture,"CategoryID", searchFilter,ListMessage.RootID);
                responseMessage.Categories = new List<CategoryConstraints>();
                foreach (Category category in category_result)
                {
                    responseMessage.Categories.Add( ConvertCategoryToConstraints( category, culture) );
                }
            }
            catch (Exception e)
            {
                WebUtilities.LogError( e );
                responseMessage.ErrorMessage = "Error: Cannot get categories from repository";
            }

            return responseMessage;
        }
    }
}
