﻿using System;
using System.Collections.Generic;
using System.Text;
using System.ServiceModel;
using Vevo.WebServices.Base;
using Vevo.WebServices.Security;
using Vevo.WebServices.SearchFilters;
using Vevo.WebAppLib;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain;
using System.Data;
using Vevo.Domain.Users;

namespace Vevo.WebServices.Countries
{
    public class CountryService : ICountryService
    {
        private CountryConstraints ConvertCountryToConstraints( Country country )
        {
            CountryConstraints constraints = new CountryConstraints();
            constraints.Capital = country.Capital;
            constraints.CommonName = country.CommonName;
            constraints.CountryCode = country.CountryCode;
            constraints.CountryCode3 = country.CountryCode3;
            constraints.CountryNumber = country.CountryNumber;
            constraints.CountrySubType = country.CountrySubType;
            constraints.CountryType = country.CountryType;
            constraints.CurrencyCode = country.CurrencyCode;
            constraints.CurrencyName = country.CurrencyName;
            constraints.Enabled = country.Enabled;
            constraints.FormalName = country.FormalName;
            constraints.InternetCountryCode = country.InternetCountryCode;
            constraints.SortOrder = country.SortOrder;
            constraints.Sovereignty = country.Sovereignty;
            constraints.TelephoneCode = country.TelephoneCode;

            return constraints;
        }

        public CountryListResponseMessage ListCountries( RequestMessage ListMessage )
        {
            CountryListResponseMessage responseMessage = new CountryListResponseMessage();
            if ( WcfSessionPool.GetSession( ListMessage.Ticket ) == null )
            {
                responseMessage.ErrorMessage = "Error: Authentication is failed.";
                return responseMessage;
            }
            try
            {
                IList<Country> country_result = DataAccessContext.CountryRepository.GetAll( BoolFilter.ShowAll, "CountryCode" );
                responseMessage.Countries = new List<CountryConstraints>();
                foreach ( Country country in country_result )
                {
                    responseMessage.Countries.Add( ConvertCountryToConstraints( country ) );
                }
            }
            catch ( Exception e )
            {
                WebUtilities.LogError( e );
                responseMessage.ErrorMessage = "Error: Cannot get countries from repository";
            }

            return responseMessage;
        }
    }
}
