using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Data;
using System.Text;
using System.Web;
using System.Web.UI;
using Vevo;
using Vevo.DataAccessLib;
using Vevo.Shared.DataAccess;

namespace Vevo.WebUI.DataAccessCache
{
    internal class BaseDataAccessCache
    {
        #region Private
        private string _className;

        private Dictionary<string, IDictionaryCache> _cacheObjects = new Dictionary<string, IDictionaryCache>();


        private IDictionaryCache GetCachedObject( string methodName )
        {
            if (!_cacheObjects.ContainsKey( methodName ))
            {
                _cacheObjects[methodName] =
                    new DictionaryCache<string, object>( _className + "Cache_" + methodName );
            }
            return _cacheObjects[methodName];
        }
        #endregion


        #region Protected
        protected string GenerateKey( params string[] parameters )
        {
            StringBuilder sb = new StringBuilder();

            for (int i = 0; i < parameters.Length; i++)
            {
                sb.Append( parameters[i] );

                if (i + 1 < parameters.Length)
                    sb.Append( "_" );
            }

            return sb.ToString();
        }


        protected object CachedMethod(
            string methodName,
            MethodNoParameter method )
        {
            DictionaryCache<string, object> cachedObject =
                (DictionaryCache<string, object>) GetCachedObject( methodName );

            string key = "Default";

            object value = cachedObject[key];
            if (value == null)
            {
                value = method();
                cachedObject[key] = value;
            }

            return value;
        }

        protected object CachedMethod(
            string methodName,
            MethodString method,
            string param1 )
        {
            DictionaryCache<string, object> cachedObject =
                (DictionaryCache<string, object>) GetCachedObject( methodName );

            string key = GenerateKey( param1 );

            object value = cachedObject[key];
            if (value == null)
            {
                value = method( param1 );
                cachedObject[key] = value;
            }

            return value;
        }

        protected object CachedMethod(
            string methodName,
            MethodBool method,
            bool param1 )
        {
            DictionaryCache<string, object> cachedObject =
                (DictionaryCache<string, object>) GetCachedObject( methodName );

            string key = GenerateKey( param1.ToString() );

            object value = cachedObject[key];
            if (value == null)
            {
                value = method( param1 );
                cachedObject[key] = value;
            }

            return value;
        }

        protected bool CachedMethodBool(
            string methodName,
            MethodString_Bool method,
            string param1 )
        {
            DictionaryCache<string, object> cachedObject =
                (DictionaryCache<string, object>) GetCachedObject( methodName );

            string key = GenerateKey( param1 );

            bool value;
            if (cachedObject.ContainsKey( key ))
            {
                value = (bool) cachedObject[key];
            }
            else
            {
                value = method( key );
                cachedObject[key] = value;
            }

            return value;
        }

        protected object CachedMethod(
            string methodName,
            MethodStringString method,
            string param1,
            string param2 )
        {
            DictionaryCache<string, object> cachedObject =
                (DictionaryCache<string, object>) GetCachedObject( methodName );

            string key = GenerateKey( param1, param2 );

            object value = cachedObject[key];
            if (value == null)
            {
                value = method( param1, param2 );
                cachedObject[key] = value;
            }

            return value;
        }

        protected object CachedMethod(
            string methodName,
            MethodStringBool method,
            string param1,
            bool param2 )
        {
            DictionaryCache<string, object> cachedObject =
                (DictionaryCache<string, object>) GetCachedObject( methodName );

            string key = GenerateKey( param1, param2.ToString() );

            object value = cachedObject[key];
            if (value == null)
            {
                value = method( param1, param2 );
                cachedObject[key] = value;
            }

            return value;
        }

        protected object CachedMethod(
            string methodName,
            MethodStringStringFlagFilter method,
            string param1,
            string param2,
            FlagFilter param3 )
        {
            DictionaryCache<string, object> cachedObject =
                (DictionaryCache<string, object>) GetCachedObject( methodName );

            string key = GenerateKey( param1, param2, param3.ToString() );

            object value = cachedObject[key];
            if (value == null)
            {
                value = method( param1, param2, param3 );
                cachedObject[key] = value;
            }

            return value;
        }

        protected object CachedMethod(
            string methodName,
            MethodStringStringStringFlagFilter method,
            string param1,
            string param2,
            string param3,
            FlagFilter param4 )
        {
            DictionaryCache<string, object> cachedObject =
                (DictionaryCache<string, object>) GetCachedObject( methodName );

            string key = GenerateKey( param1, param2, param3, param4.ToString() );

            object value = cachedObject[key];
            if (value == null)
            {
                value = method( param1, param2, param3, param4 );
                cachedObject[key] = value;
            }

            return value;
        }

        protected object CachedMethod(
            string methodName,
            MethodStringStringStringFlagFilterIntIntOutInt method,
            string param1,
            string param2,
            string param3,
            FlagFilter param4,
            int param5,
            int param6,
            out int outParam1 )
        {
            DictionaryCache<string, object> cachedObject =
                (DictionaryCache<string, object>) GetCachedObject( methodName );

            string key = GenerateKey(
                param1, param2, param3, param4.ToString(), param5.ToString(), param6.ToString() );

            Pair value;
            if (cachedObject.ContainsKey( key ))
            {
                value = (Pair) cachedObject[key];
            }
            else
            {
                int outTemp1;
                object result;
                result = method( param1, param2, param3, param4, param5, param6, out outTemp1 );

                value = new Pair( result, outTemp1 );
                cachedObject[key] = value;
            }

            outParam1 = (int) value.Second;
            return value.First;
        }
        #endregion


        #region Public Delegate
        
        // The convention for naming these delegates for caching are as follows:
        // 
        // For delegates returning type of object:
        //      Method[ParamType1][ParamType2][...]
        //
        // For delegates returning other types:
        //      Method[ParamType1][ParamType2][...]_ReturnType

        public delegate object MethodNoParameter();

        public delegate object MethodString( string param1 );

        public delegate object MethodBool( bool param1 );

        public delegate bool MethodString_Bool( string param1 );

        public delegate object MethodStringString( string param1, string param2 );

        public delegate object MethodStringBool( string param1, bool param2 );

        public delegate object MethodStringStringFlagFilter(
            string param1,
            string param2,
            FlagFilter param3 );

        public delegate object MethodStringStringStringFlagFilter(
            string param1,
            string param2,
            string param3,
            FlagFilter param4 );

        public delegate object MethodStringStringStringFlagFilterIntIntOutInt(
            string param1,
            string param2,
            string param3,
            FlagFilter param4,
            int param5,
            int param6,
            out int outParam1 );
        #endregion


        public BaseDataAccessCache( string className )
        {
            _className = className;
        }

        public virtual void ClearCache()
        {
            IDictionaryEnumerator cacheEnum = _cacheObjects.GetEnumerator();
            while (cacheEnum.MoveNext())
            {
                IDictionaryCache cache = (IDictionaryCache) cacheEnum.Value;
                cache.ClearCache();
            }

            _cacheObjects.Clear();
        }

    }
}
